@@ -3,7 +3,6 @@ details, see https://github.com/refresh-bio/FAMSA.
 
 """
 
-import os
 import subprocess
 from pathlib import Path
 
@@ -23,8 +22,7 @@ from albion_similog.log import setup_logger
 
 logger = setup_logger(__name__)
 
-PROJECT_DIR = Path(os.path.dirname(os.path.realpath(__file__))).parent
-FAMSA_PATH = PROJECT_DIR / "famsa-workdir"
+FAMSA_PATH = Path("/tmp/famsa-workdir")
 FAMSA_PATH.mkdir(exist_ok=True)
 
 
@@ -378,7 +376,7 @@ class WellCorrelation:
         logger.info("Run FAMSA program on %s.", self.sequence_filepath)
         subprocess.call(
             [
-                str(PROJECT_DIR / "famsa"),
+                "famsa",
                 "-go",
                 "20",
                 "-ge",
